@@ -20,7 +20,6 @@ def label_assignment_cost(labels1,labels2,label1,label2):
 
 def get_trans_dict(trans_from_labels,trans_to_labels,subsample_size):
     # First compress each labelling, retain compression dicts
-    subsample_size = min(len(trans_from_labels),subsample_size)
     trans_from_labels, tdf, _ = compress_labels(trans_from_labels)
     trans_to_labels, tdt, _ = compress_labels(trans_to_labels)
     reverse_tdf = {v:k for k,v in tdf.items()}
@@ -28,7 +27,9 @@ def get_trans_dict(trans_from_labels,trans_to_labels,subsample_size):
     assert trans_from_labels.shape == trans_to_labels.shape
     num_from_labs = get_num_labels(trans_from_labels)
     num_to_labs = get_num_labels(trans_to_labels)
-    assert subsample_size == 'none' or subsample_size > min(num_from_labs,num_to_labs)
+    if subsample_size != 'none':
+        assert subsample_size > min(num_from_labs,num_to_labs)
+        subsample_size = min(len(trans_from_labels),subsample_size)
     if num_from_labs <= num_to_labs:
         trans_dict = get_fanout_trans_dict(trans_from_labels,trans_to_labels,subsample_size)
         leftovers = np.array([x for x in unique_labels(trans_to_labels) if x not in trans_dict.values()])
@@ -134,7 +135,7 @@ def f1(bin_classifs_pred,bin_classifs_gt):
     rec = tp/(tp+fn)
     return (2*prec*rec)/(prec+rec)
 
-def mean_f1(labels1,labels2,subsample_size=30000):
+def mean_f1(labels1,labels2,subsample_size='none'):
     trans_labels = translate_labellings(labels1,labels2,subsample_size)
     lab_f1s = []
     for lab in unique_labels(trans_labels):
